fixed typo :p
authorhackbard <hackbard>
Sat, 29 Mar 2003 00:56:56 +0000 (00:56 +0000)
committerhackbard <hackbard>
Sat, 29 Mar 2003 00:56:56 +0000 (00:56 +0000)
main.c

diff --git a/main.c b/main.c
index 9306e60..66503ee 100644 (file)
--- a/main.c
+++ b/main.c
@@ -46,7 +46,7 @@ int usage()
  puts("-d <value> \t refresh every <value> loops (default 100)");
  puts("-r <value> \t pressure range from amorphous SiCx (default 2)");
  puts("-f <value> \t (unused) faktor for pressure from amorphous SiCx (default 1)");
- puts("-p <value> \t p0 for propability of cell getting amorph (default sum_range_rate / 4)");
+ puts("-p <value> \t p0 for probability of cell getting amorph (default sum_range_rate / 4)");
  return -23;
 }
 
@@ -86,7 +86,7 @@ int process_cell(void *cell_p,u32 x,u32 y,u32 z,u32 x_max,u32 y_max,u32 z_max,in
  // count+=faktor*1.0/(i*i+j*j+k*k);
  if(*cell&AMORPH)
  {
/* wrong propability! just test by now ...*/
   if(rand_get(sum_range_rate)>count) make_cryst(cell);
  } else
  {
@@ -86,7 +86,7 @@ int process_cell(void *cell_p,u32 x,u32 y,u32 z,u32 x_max,u32 y_max,u32 z_max,in
  if(*cell&AMORPH)
  {
-  /* wrong propability! just test by now ...*/
+  /* wrong probability! just test by now ...*/
   if(rand_get(sum_range_rate)>count) make_cryst(cell);
  } else